<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:java="java" exclude-result-prefixes="fo">

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<xsl:param name="body.font.family" expression="Arial, FreeSans" />
	<xsl:param name="title.font.family" expression="Arial, FreeSans" />
	<xsl:param name="monospace.font.family" expression="Arial, FreeSans" />
	<!-- <xsl:param name="body.font.master" select="'10.1'" /> -->
	<xsl:param name="symbol.font.family" expression="Arial, FreeSans" />
	<xsl:param name="body.fontset" expression="Arial, FreeSans" />

	<xsl:include href="template://Barcode_Template.xsl" />

	<!-- ============================== -->
	<!-- Template: Report A4 Landscape -->
	<!-- ============================== -->

	<xsl:template match="report">
		<fo:root font-family="Arial, FreeSans">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="whole_page" page-width="297mm" page-height="210mm" margin-top="5mm"
					margin-bottom="5mm" margin-left="10mm" margin-right="10mm">
					<fo:region-body margin-left="0" margin-right="0" margin-top="21mm" margin-bottom="21mm" />
					<fo:region-before extent="20mm" />
					<fo:region-after extent="10mm" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="whole_page">

				<fo:static-content flow-name="xsl-region-before">
					<!-- Header begin -->
					<fo:block>
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<!-- Company info -->

										<!-- Barcode CargoNetID -->
										<fo:block padding="0.1mm" text-align="left">
											<xsl:call-template name="barcode">
												<xsl:with-param name="message" select="/report/shipperInfo/cargoNetID" />
												<xsl:with-param name="fontSize" select="'3mm'" />
												<xsl:with-param name="height" select="'7mm'" />
											</xsl:call-template>
										</fo:block>

										<fo:block font-size="4.5mm" font-weight="bold" font-style="italic" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/shipperInfo/name" />
										</fo:block>
										<fo:block font-size="3mm" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/shipperInfo/address" />
											<xsl:text>, </xsl:text>
											<xsl:value-of select="/report/shipperInfo/postalCode" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/shipperInfo/city" />
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- Report header -->
										<fo:block font-size="4.5mm" font-weight="bold" text-align="center" wrap-option="no-wrap" margin-bottom="2mm">
											<xsl:value-of select="/report/reportTitle" />
										</fo:block>
										<fo:block text-align="center">
											<fo:table width="55mm">
												<fo:table-body>
													<fo:table-row>
														<fo:table-cell padding-right="5mm">
															<fo:block font-style="italic" text-align="left">
																<xsl:value-of select="/report/centerLabel" />
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block text-align="left">
																<xsl:value-of select="/report/centerValue" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
													<fo:table-row>
														<fo:table-cell padding-right="5mm">
															<fo:block font-style="italic" text-align="left">
																<xsl:value-of select="/report/datumLabel" />
															</fo:block>
														</fo:table-cell>
														<fo:table-cell>
															<fo:block font-weight="bold" text-align="left" wrap-option="no-wrap">
																<xsl:value-of select="/report/datumValue" />
															</fo:block>
														</fo:table-cell>
													</fo:table-row>
												</fo:table-body>
											</fo:table>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<!-- City logo -->
										<fo:block font-size="4.5mm" font-weight="bold" font-style="italic" text-align="right" wrap-option="no-wrap">
											<xsl:value-of select="/report/licenseeInfo/name" />
										</fo:block>
										<fo:block font-size="3mm" text-align="right" wrap-option="no-wrap">
											<xsl:value-of select="/report/licenseeInfo/address" />
											<xsl:text>, </xsl:text>
											<xsl:value-of select="/report/licenseeInfo/postalCode" />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/licenseeInfo/city" />
										</fo:block>
										<fo:block font-size="3mm" text-align="right" font-style="italic" wrap-option="no-wrap">
											<xsl:value-of select="/report/licenseeInfo/httpAddress" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Header end -->
				</fo:static-content>

				<fo:static-content flow-name="xsl-region-after">
					<!-- Footer begin -->
					<fo:block padding-top="1mm" border-style="solid" border-width="0" border-top-width="thin">
						<fo:table width="100%">
							<fo:table-body>
								<fo:table-row>
									<fo:table-cell>
										<fo:block font-size="2.5mm" text-align="left" wrap-option="no-wrap">
											<xsl:value-of select="/report/licenseeInfo/shortDescription" />
										</fo:block>
										<fo:block font-size="2.5mm" text-align="left" font-style="italic" wrap-option="no-wrap">
											<xsl:value-of select="/report/expeditInfo/name" />
											<!-- <xsl:text>, </xsl:text> <xsl:value-of select="/report/expeditInfo/httpAddress" /> -->
										</fo:block>
									</fo:table-cell>
									<fo:table-cell>
										<fo:block font-size="3mm" text-align="right" wrap-option="no-wrap">
											<xsl:value-of select="/report/pageLabel" />
											<xsl:text> </xsl:text>
											<fo:page-number />
											<xsl:text> </xsl:text>
											<xsl:value-of select="/report/pageOfLabel" />
											<xsl:text> </xsl:text>
											<fo:page-number-citation ref-id="endOfDocument" />
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<!-- Footer end -->
				</fo:static-content>

				<fo:flow flow-name="xsl-region-body">
					<fo:block>
						<!-- Main content begin -->
						<xsl:for-each select="shipmentsInfo/shipmentInfo">
							<fo:block padding-top="1mm" padding-bottom="1mm" border-style="solid" border-width="0" border-top-width="thin">
								<xsl:apply-templates select="." />
							</fo:block>
						</xsl:for-each>
						<!-- Main content end -->

						<!-- Signatures part begin -->
						<fo:footnote>
							<fo:inline />
							<fo:footnote-body>
								<fo:block padding-top="2mm">
									<fo:table width="100%">
										<fo:table-body>
											<fo:table-row>
												<fo:table-cell width="70mm" margin-right="5mm">
													<fo:block font-size="3mm" text-align="left" wrap-option="no-wrap" margin-bottom="0.5mm">
														<xsl:value-of select="/report/currierSignatureLabel" />
													</fo:block>
													<fo:block border-style="solid" line-height="12mm" border-width="thin" color="#FFFFFF">
														<xsl:text>.</xsl:text>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell width="70mm" margin-right="5mm">
													<fo:block font-size="3mm" text-align="left" wrap-option="no-wrap" margin-bottom="0.5mm">
														<xsl:value-of select="/report/senderSignatureLabel" />
													</fo:block>
													<fo:block border-style="solid" line-height="12mm" border-width="thin" color="#FFFFFF">
														<xsl:text>.</xsl:text>
													</fo:block>
												</fo:table-cell>
												<fo:table-cell display-align="center">
													<fo:block font-size="2.5mm" text-align="left" margin="1mm">
														<xsl:value-of select="/report/agreementTextLabel" />
													</fo:block>
												</fo:table-cell>
												<fo:table-cell width="40mm" margin-left="5mm">
													<fo:block font-size="4mm" font-weight="bold" text-decoration="underline" text-align="right" wrap-option="no-wrap"
														margin-bottom="0.5mm">
														<xsl:value-of select="/report/totalNumberOfParcelsLabel" />
														<xsl:text>: </xsl:text>
														<xsl:value-of select="/report/totalNumberOfParcelsValue" />
													</fo:block>
												</fo:table-cell>
											</fo:table-row>
										</fo:table-body>
									</fo:table>
								</fo:block>
							</fo:footnote-body>
						</fo:footnote>
						<!-- Signatures part end -->

					</fo:block>
					<fo:block id="endOfDocument" />
				</fo:flow>

			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="shipmentInfo">
		<fo:table width="100%">
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell keep-together="always">
						<fo:block font-size="2.5mm" text-align="left" wrap-option="no-wrap">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>

										<!-- Sender info -->
										<fo:table-cell width="40mm">
											<fo:block font-size="2.5mm" text-align="left">
												<xsl:value-of select="/report/shipmentReferenceNr1Label" />
											</fo:block>
											<fo:block text-align="left" margin-bottom="1mm" keep-with-previous.within-page="always">
												<xsl:choose>
													<xsl:when test="referenceNr1 = ''">
														<xsl:text>-</xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:call-template name="barcode">
															<xsl:with-param name="message" select="referenceNr1" />
															<xsl:with-param name="fontSize" select="'2.5mm'" />
															<xsl:with-param name="height" select="'7mm'" />
															<xsl:param name="placement" select="'top'" />
														</xsl:call-template>
													</xsl:otherwise>
												</xsl:choose>
											</fo:block>
											<fo:block font-size="2.5mm" text-align="left" keep-with-previous.within-page="always">
												<xsl:value-of select="/report/shipmentSenderNameLabel" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" keep-with-previous.within-page="always">
												<xsl:value-of select="senderName" />
											</fo:block>
										</fo:table-cell>

										<!-- Receiver info -->
										<fo:table-cell width="45mm">
											<fo:block font-size="2.5mm" text-align="left">
												<xsl:value-of select="/report/shipmentReceiverNameLabel" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" font-weight="bold" keep-with-previous.within-page="always">
												<xsl:value-of select="receiverName" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" keep-with-previous.within-page="always">
												<xsl:value-of select="receiverAddress" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" keep-with-previous.within-page="always">
												<xsl:value-of select="receiverPostalCode" />
												<xsl:text> </xsl:text>
												<xsl:value-of select="receiverCity" />
											</fo:block>
											<fo:block font-size="2.5mm" text-align="left" margin-top="1mm" keep-with-previous.within-page="always">
												<xsl:value-of select="/report/shipmentContactPersonNameLabel" />
											</fo:block>
											<fo:block font-size="3mm" text-align="left" font-weight="bold" keep-with-previous.within-page="always">
												<xsl:value-of select="contactPersonName" />
											</fo:block>
										</fo:table-cell>

										<!-- Packet info -->
										<fo:table-cell>
											<fo:block font-size="2.8mm" text-align="left">
												<xsl:value-of select="concat(/report/shipmentRemarkLabel, ': ', remark)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/shipmentNumberOfPacketsLabel, ': ', numberOfPackets)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/shipmentBillBaseTypeLabel, ': ', billBaseType)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(billBaseType, ': ', billBaseValue)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/shipmentCashOnDeliveryValueLabel, ': ', cashOnDeliveryValue)" />
											</fo:block>
											<fo:block font-size="2.8mm" text-align="left" margin-top="0.5mm" keep-with-previous.within-page="always">
												<xsl:value-of select="concat(/report/shipmentInsuranceValueLabel, ': ', insuranceValue)" />
											</fo:block>
										</fo:table-cell>

										<!-- Services info -->
										<fo:table-cell width="35mm">
											<xsl:for-each select="service">
												<xsl:variable name="topMargin">
													<xsl:choose>
														<xsl:when test="groupLeader = 'true'">
															<xsl:text>1mm</xsl:text>
														</xsl:when>
														<xsl:otherwise>
															<xsl:text>0</xsl:text>
														</xsl:otherwise>
													</xsl:choose>
												</xsl:variable>
												<xsl:choose>
													<xsl:when test="enabled = 'true'">
														<fo:block font-size="2.5mm" font-weight="bold" font-style="italic" text-align="left" margin-top="{$topMargin}">
															<xsl:value-of select="name" />
															<!-- <fo:inline padding-left="1mm"> <xsl:text>&#8658;</xsl:text> </fo:inline> -->
														</fo:block>
													</xsl:when>
													<xsl:otherwise>
														<fo:block font-size="2mm" text-align="left" margin-top="{$topMargin}" text-decoration="line-through">
															<xsl:value-of select="name" />
														</fo:block>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:for-each>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell width="95mm">
						<fo:block>
							<fo:table width="100%">
								<fo:table-body>
									<xsl:for-each select="packetsInfo/packetsRow">
										<fo:table-row>
											<xsl:for-each select="packetCode">
												<fo:table-cell margin-left="3mm">
													<fo:block padding="0">
														<xsl:call-template name="barcode">
															<xsl:with-param name="message" select="." />
															<xsl:with-param name="codeType" select="'intl2of5'" />
															<xsl:with-param name="fontSize" select="'3mm'" />
															<xsl:with-param name="height" select="'10mm'" />
														</xsl:call-template>
													</fo:block>
												</fo:table-cell>
											</xsl:for-each>
										</fo:table-row>
									</xsl:for-each>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

</xsl:stylesheet>

